==> elevarm_ui-0.8.1.tar.gz: lib/src/components/cards/elevarm_view_detail_card.dart <==
import 'package:elevarm_icons/elevarm_icons.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

enum ElevarmViewDetailCardVariant {
  white,
  primary,
}

class ElevarmViewDetailCard extends StatelessWidget {
  final String leadingIconAssetName;
  final String title;
  final ElevarmViewDetailCardVariant variant;
  final String trailingIconAssetName;
  final Function(BuildContext context) onTap;

  const ElevarmViewDetailCard({
    super.key,
    required this.leadingIconAssetName,
    required this.title,
    this.variant = ElevarmViewDetailCardVariant.white,
    this.trailingIconAssetName = ElevarmIconsOutline.arrowRight,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    late Color backgroundColor;
    late Color borderColor;
    late Color leadingIconColor;
    late Color textColor;
    late Color trailingIconColor;
    switch (variant) {
      case ElevarmViewDetailCardVariant.white:
        backgroundColor = ElevarmColors.white;
        borderColor = ElevarmColors.neutral100;
        leadingIconColor = ElevarmColors.neutral300;
        textColor = ElevarmColors.neutral400;
        trailingIconColor = ElevarmColors.primary;
        break;
      case ElevarmViewDetailCardVariant.primary:
        backgroundColor = ElevarmColors.primary600;
        borderColor = ElevarmColors.primary600;
        leadingIconColor = ElevarmColors.primary200;
        textColor = ElevarmColors.primary100;
        trailingIconColor = ElevarmColors.primary100;
        break;
    }

    return Material(
      color: backgroundColor,
      borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
      child: InkWell(
        borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
        onTap: () {
          onTap(context);
        },
        child: Container(
          decoration: BoxDecoration(
            border: Border.all(
              color: borderColor,
            ),
            // color: backgroundColor,
            borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
          ),
          padding: const EdgeInsets.all(16),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              ElevarmIcon(
                leadingIconAssetName,
                color: leadingIconColor,
                height: 16.0,
                width: 16.0,
              ),
              const SizedBox(width: 8.0),
              Expanded(
                child: Text(
                  title,
                  style: ElevarmFontFamilies.inter(
                    fontSize: ElevarmFontSizes.sm,
                    fontWeight: ElevarmFontWeights.medium,
                    color: textColor,
                  ),
                ),
              ),
              const SizedBox(width: 8.0),
              ElevarmIcon(
                trailingIconAssetName,
                color: trailingIconColor,
                height: 16.0,
                width: 16.0,
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> elevarm_ui-0.9.4.tar.gz: lib/src/components/cards/elevarm_view_detail_card.dart <==
import 'package:elevarm_icons/elevarm_icons.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

enum ElevarmViewDetailCardVariant {
  white,
  primary,
}

class ElevarmViewDetailCard extends StatelessWidget {
  final IconData leadingIconAssetName;
  final String title;
  final ElevarmViewDetailCardVariant variant;
  final IconData trailingIconAssetName;
  final Function(BuildContext context) onTap;

  const ElevarmViewDetailCard({
    super.key,
    required this.leadingIconAssetName,
    required this.title,
    this.variant = ElevarmViewDetailCardVariant.white,
    this.trailingIconAssetName = ElevarmIconsOutline.arrow_right,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    late Color backgroundColor;
    late Color borderColor;
    late Color leadingIconColor;
    late Color textColor;
    late Color trailingIconColor;
    switch (variant) {
      case ElevarmViewDetailCardVariant.white:
        backgroundColor = ElevarmColors.white;
        borderColor = ElevarmColors.neutral100;
        leadingIconColor = ElevarmColors.neutral300;
        textColor = ElevarmColors.neutral400;
        trailingIconColor = ElevarmColors.primary;
        break;
      case ElevarmViewDetailCardVariant.primary:
        backgroundColor = ElevarmColors.primary600;
        borderColor = ElevarmColors.primary600;
        leadingIconColor = ElevarmColors.primary200;
        textColor = ElevarmColors.primary100;
        trailingIconColor = ElevarmColors.primary100;
        break;
    }

    return Material(
      color: backgroundColor,
      borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
      child: InkWell(
        borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
        onTap: () {
          onTap(context);
        },
        child: Container(
          decoration: BoxDecoration(
            border: Border.all(
              color: borderColor,
            ),
            // color: backgroundColor,
            borderRadius: BorderRadius.circular(ElevarmBorderRadius.sm),
          ),
          padding: const EdgeInsets.all(16),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              ElevarmIcon(
                leadingIconAssetName,
                color: leadingIconColor,
                size: 16.0,
              ),
              const SizedBox(width: 8.0),
              Expanded(
                child: Text(
                  title,
                  style: ElevarmFontFamilies.inter(
                    fontSize: ElevarmFontSizes.sm,
                    fontWeight: ElevarmFontWeights.medium,
                    color: textColor,
                  ),
                ),
              ),
              const SizedBox(width: 8.0),
              ElevarmIcon(
                trailingIconAssetName,
                color: trailingIconColor,
                size: 16.0,
              ),
            ],
          ),
        ),
      ),
    );
  }
}
